@@ -64,6 +64,11 @@ void MainWindow::createContextMenu()
     connect(ui->lstThemes, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(themeMenuSlot(QPoint)));
 }
 
+bool toAssending( const Theme* s1 , const Theme* s2 )
+{
+    return s1->name < s2->name;
+}
+
 void MainWindow::getThemesList()
 {
     m_Themes.clear();
@@ -96,6 +101,7 @@ void MainWindow::getThemesList()
             t->screenshot = QPixmap(filename);
         }
     }
+    qSort( m_Themes.begin() , m_Themes.end(), toAssending );
 
     ui->lstThemes->clear();
     foreach (Theme* t, m_Themes){
@@ -187,17 +193,21 @@ void MainWindow::setActiveThemeSlot()
     QProcess p;
     p.start("rm -f /home/user/.config/sakya/QtLockscreen.ini");
     p.waitForFinished(-1);
+    if (p.exitCode() != 0)
+        qDebug() << "Error removing /home/user/.config/sakya/QtLockscreen.in";
 
     p.start(QString("ln -s \"%1\" /home/user/.config/sakya/QtLockscreen.ini").arg(t->file));
     p.waitForFinished(-1);
+    if (p.exitCode() != 0)
+        qDebug() << "Error creating /home/user/.config/sakya/QtLockscreen.in";
 
-    p.start("pkill -HUP -f /usr/bin/qtlockscreen");
+    p.start("sh -c \"pkill -HUP -f /usr/bin/qtlockscreen\"");
     p.waitForFinished(-1);
+    if (p.exitCode() != 0)
+        qDebug() << "Error restarting /usr/bin/qtlockscreen";
 
-    /*p.start("sh -c \"if [ ! -n \\\"$(pidof qtlockscreen)\\\" ]; then echo '1'; fi\"");
+    p.start("sh -c \"sleep 2; if [ -z \"$(pidof qtlockscreen)\" ]; then bg qtlockscreen; fi\"");
     p.waitForFinished(-1);
-    QString res = p.readAll();
-    qDebug() << "Result:" << res;*/
 
     setEnabled(true);
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
@@ -245,6 +255,8 @@ void MainWindow::clearCacheSlot()
     qDebug() << cmd;
     p.start(cmd);
     p.waitForFinished(-1);
+    if (p.exitCode() != 0)
+        qDebug() << "Error deleting screenshots";
 
     m_ScrenshotMaker = new ScreenshotMaker(this, m_Themes);
     connect(m_ScrenshotMaker, SIGNAL(screenshot(Theme*,QString)), this, SLOT(onNewScreenshot(Theme*, QString)));
