@@ -32,8 +32,8 @@ private:
 
     void createMainMenu();
     void createContextMenu();
-    QMessageBox::StandardButton ConfirmMessage(QWidget* parent, QString title, QString message);
-    void InfoMessage(QWidget* parent, QString message);
+    QMessageBox::StandardButton confirmMessage(QWidget* parent, QString title, QString message);
+    void infoMessage(QWidget* parent, QString message);
 
 private slots:
     void onListDoubleClicked(QModelIndex);
@@ -46,6 +46,7 @@ private slots:
     void setActiveThemeSlot();
     void updateScreenshotThemeSlot();
     void clearCacheSlot();
+    void aboutSlot();
 };
 
 #endif // MAINWINDOW_H
